@@ -6,8 +6,8 @@ use strict;
 use vars qw($VERSION $VERSION_DATE $DEBUG);
 
 # Globals
-$VERSION = '0.46';
-$VERSION_DATE = '2012/01/11';
+$VERSION = '0.48';
+$VERSION_DATE = '2015/03/26';
 
 # Set this up to 3
 $DEBUG = 0;
@@ -1018,7 +1018,7 @@ sub _put {
             }
             else {
                 binmode F;
-                while (<F>) { $content .= $_; }
+                while (my $line = <F>) { $content .= $line; }
                 close F;
             }
         }
